.. _pecan_testing:

:mod:`pecan.testing` -- Pecan Testing
===========================================

The :mod:`pecan.testing` module includes fixtures to help test Pecan
applications.

.. automodule:: pecan.testing
  :members:
  :show-inheritance:
